
# 🤖 InSH

[![Version](https://img.shields.io/badge/version-2.0-blue?style=for-the-badge)](https://github.com/TheSpeedX/insh) [![License](https://img.shields.io/github/license/TheSpeedX/insh?style=for-the-badge)](https://github.com/TheSpeedX/insh/blob/master/LICENSE) [![PyPI](https://img.shields.io/badge/PyPI-InSH-blue?style=for-the-badge)](https://pypi.org/project/insh/) ![Monthly Downloads](https://img.shields.io/pypi/dm/insh?style=for-the-badge) ![Views](https://img.shields.io/endpoint?style=for-the-badge&url=https%3A%2F%2Fhits.dwyl.com%2FTheSpeedX%2Finsh.json%3Fcolor%3Dblue)

Ever wished your shell had a personality? Meet [InSH](https://github.com/TheSpeedX/insh) - the Insulter Shell!

## Features

- Integrates with bash on windows and linux apparently
- Helps you with command even if you haven't asked for it
- Drains your OpenAI GPT credit for silly stuff

## Installation

Use the package manager pip:

```bash
pip install -U insh
```

Or alternatively, you can install the latest version using git:

```bash
pip install git+https://github.com/TheSpeedX/insh.git
```

## Usage

Configure the shell and OpenAI API:

```bash
insh --configure
```

Activate/Deactivate the shell extension:  

```bash
insh --activate
insh --deactivate
```

Ask it any thing:

```bash
ina "<question>"
insh --ask "<question>"
```

NOTE: You might face issues with shell integration. Feel free to create an issue for it.

## Screenshots

![Working Stuff](https://github.com/TheSpeedX/insh/assets/42498830/6cbf71cb-69a5-4dad-987c-a2d585123985)

![App Screenshot](https://github.com/TheSpeedX/insh/assets/42498830/11d7ee45-d365-4106-b1b3-7c95ea1c0455)

## Authors

Made with 💔 by [@TheSpeedX](https://www.github.com/TheSpeedX)
